@@ -55,14 +55,15 @@ import weakref
 import time
 import rospy
 from rospy import Header
-from actionlib_msgs.msg import *
-from actionlib.exceptions import *
+from actionlib_msgs.msg import GoalID, GoalStatus, GoalStatusArray
+from actionlib.exceptions import ActionException
 
 g_goal_id = 1
 
+
 def get_name_of_constant(C, n):
-    for k,v in C.__dict__.iteritems():
-        if type(v) is int and v == n:
+    for k, v in C.__dict__.items():
+        if isinstance(v, int) and v == n:
             return k
     return "NO_SUCH_STATE_%d" % n
 
@@ -78,6 +79,7 @@ class CommState(object):
     DONE = 7
     LOST = 8
 
+
 class TerminalState(object):
     RECALLED = GoalStatus.RECALLED
     REJECTED = GoalStatus.REJECTED
@@ -91,12 +93,14 @@ GoalStatus.to_string = classmethod(get_name_of_constant)
 CommState.to_string = classmethod(get_name_of_constant)
 TerminalState.to_string = classmethod(get_name_of_constant)
 
+
 def _find_status_by_goal_id(status_array, id):
     for s in status_array.status_list:
         if s.goal_id.id == id:
             return s
     return None
 
+
 ## @brief Client side handle to monitor goal progress.
 ##
 ## A ClientGoalHandle is a reference counted object that is used to
@@ -111,7 +115,7 @@ class ClientGoalHandle:
     def __init__(self, comm_state_machine):
         self.comm_state_machine = comm_state_machine
 
-        #print "GH created.  id = %.3f" % self.comm_state_machine.action_goal.goal_id.stamp.to_sec()
+        # print "GH created.  id = %.3f" % self.comm_state_machine.action_goal.goal_id.stamp.to_sec()
 
     ## @brief True iff the two ClientGoalHandle's are tracking the same goal
     def __eq__(self, o):
@@ -125,14 +129,17 @@ class ClientGoalHandle:
             return True
         return not (self.comm_state_machine == o.comm_state_machine)
 
+    ## @brieft Hash function for ClientGoalHandle
+    def __hash__(self):
+        return hash(self.comm_state_machine)
 
     ## @brief Sends a cancel message for this specific goal to the ActionServer.
     ##
     ## Also transitions the client state to WAITING_FOR_CANCEL_ACK
     def cancel(self):
         with self.comm_state_machine.mutex:
-            cancel_msg = GoalID(stamp = rospy.Time(0),
-                                id = self.comm_state_machine.action_goal.goal_id.id)
+            cancel_msg = GoalID(stamp=rospy.Time(0),
+                                id=self.comm_state_machine.action_goal.goal_id.id)
             self.comm_state_machine.send_cancel_fn(cancel_msg)
             self.comm_state_machine.transition_to(CommState.WAITING_FOR_CANCEL_ACK)
 
@@ -179,7 +186,7 @@ class ClientGoalHandle:
             rospy.logerr("Trying to get_result on an inactive ClientGoalHandle.")
             return None
         if not self.comm_state_machine.latest_result:
-            #rospy.logerr("Trying to get_result on a ClientGoalHandle when no result has been received.")
+            # rospy.logerr("Trying to get_result on a ClientGoalHandle when no result has been received.")
             return None
         return self.comm_state_machine.latest_result.result
 
@@ -197,7 +204,7 @@ class ClientGoalHandle:
         with self.comm_state_machine.mutex:
             if self.comm_state_machine.state != CommState.DONE:
                 rospy.logwarn("Asking for the terminal state when we're in [%s]",
-                             CommState.to_string(self.comm_state_machine.state))
+                              CommState.to_string(self.comm_state_machine.state))
 
             goal_status = self.comm_state_machine.latest_goal_status.status
             if goal_status in [GoalStatus.PREEMPTED, GoalStatus.SUCCEEDED,
@@ -209,8 +216,6 @@ class ClientGoalHandle:
             return GoalStatus.LOST
 
 
-
-
 NO_TRANSITION = -1
 INVALID_TRANSITION = -2
 _transitions = {
@@ -223,7 +228,7 @@ _transitions = {
         GoalStatus.PREEMPTED:  (CommState.ACTIVE, CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
         GoalStatus.SUCCEEDED:  (CommState.ACTIVE, CommState.WAITING_FOR_RESULT),
         GoalStatus.ABORTED:    (CommState.ACTIVE, CommState.WAITING_FOR_RESULT),
-        GoalStatus.PREEMPTING: (CommState.ACTIVE, CommState.PREEMPTING) },
+        GoalStatus.PREEMPTING: (CommState.ACTIVE, CommState.PREEMPTING)},
     CommState.PENDING: {
         GoalStatus.PENDING:    NO_TRANSITION,
         GoalStatus.ACTIVE:     CommState.ACTIVE,
@@ -233,7 +238,7 @@ _transitions = {
         GoalStatus.PREEMPTED:  (CommState.ACTIVE, CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
         GoalStatus.SUCCEEDED:  (CommState.ACTIVE, CommState.WAITING_FOR_RESULT),
         GoalStatus.ABORTED:    (CommState.ACTIVE, CommState.WAITING_FOR_RESULT),
-        GoalStatus.PREEMPTING: (CommState.ACTIVE, CommState.PREEMPTING) },
+        GoalStatus.PREEMPTING: (CommState.ACTIVE, CommState.PREEMPTING)},
     CommState.ACTIVE: {
         GoalStatus.PENDING:    INVALID_TRANSITION,
         GoalStatus.ACTIVE:     NO_TRANSITION,
@@ -243,7 +248,7 @@ _transitions = {
         GoalStatus.PREEMPTED:  (CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
         GoalStatus.SUCCEEDED:  CommState.WAITING_FOR_RESULT,
         GoalStatus.ABORTED:    CommState.WAITING_FOR_RESULT,
-        GoalStatus.PREEMPTING: CommState.PREEMPTING },
+        GoalStatus.PREEMPTING: CommState.PREEMPTING},
     CommState.WAITING_FOR_RESULT: {
         GoalStatus.PENDING:    INVALID_TRANSITION,
         GoalStatus.ACTIVE:     NO_TRANSITION,
@@ -253,7 +258,7 @@ _transitions = {
         GoalStatus.PREEMPTED:  NO_TRANSITION,
         GoalStatus.SUCCEEDED:  NO_TRANSITION,
         GoalStatus.ABORTED:    NO_TRANSITION,
-        GoalStatus.PREEMPTING: INVALID_TRANSITION },
+        GoalStatus.PREEMPTING: INVALID_TRANSITION},
     CommState.WAITING_FOR_CANCEL_ACK: {
         GoalStatus.PENDING:    NO_TRANSITION,
         GoalStatus.ACTIVE:     NO_TRANSITION,
@@ -263,7 +268,7 @@ _transitions = {
         GoalStatus.PREEMPTED:  (CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
         GoalStatus.SUCCEEDED:  (CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
         GoalStatus.ABORTED:    (CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
-        GoalStatus.PREEMPTING: CommState.PREEMPTING },
+        GoalStatus.PREEMPTING: CommState.PREEMPTING},
     CommState.RECALLING: {
         GoalStatus.PENDING:    INVALID_TRANSITION,
         GoalStatus.ACTIVE:     INVALID_TRANSITION,
@@ -273,7 +278,7 @@ _transitions = {
         GoalStatus.PREEMPTED:  (CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
         GoalStatus.SUCCEEDED:  (CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
         GoalStatus.ABORTED:    (CommState.PREEMPTING, CommState.WAITING_FOR_RESULT),
-        GoalStatus.PREEMPTING: CommState.PREEMPTING },
+        GoalStatus.PREEMPTING: CommState.PREEMPTING},
     CommState.PREEMPTING: {
         GoalStatus.PENDING:    INVALID_TRANSITION,
         GoalStatus.ACTIVE:     INVALID_TRANSITION,
@@ -283,7 +288,7 @@ _transitions = {
         GoalStatus.PREEMPTED:  CommState.WAITING_FOR_RESULT,
         GoalStatus.SUCCEEDED:  CommState.WAITING_FOR_RESULT,
         GoalStatus.ABORTED:    CommState.WAITING_FOR_RESULT,
-        GoalStatus.PREEMPTING: NO_TRANSITION },
+        GoalStatus.PREEMPTING: NO_TRANSITION},
     CommState.DONE: {
         GoalStatus.PENDING:    INVALID_TRANSITION,
         GoalStatus.ACTIVE:     INVALID_TRANSITION,
@@ -293,8 +298,7 @@ _transitions = {
         GoalStatus.PREEMPTED:  NO_TRANSITION,
         GoalStatus.SUCCEEDED:  NO_TRANSITION,
         GoalStatus.ABORTED:    NO_TRANSITION,
-        GoalStatus.PREEMPTING: INVALID_TRANSITION } }
-
+        GoalStatus.PREEMPTING: INVALID_TRANSITION}}
 
 
 class CommStateMachine:
@@ -307,12 +311,16 @@ class CommStateMachine:
 
         self.state = CommState.WAITING_FOR_GOAL_ACK
         self.mutex = threading.RLock()
-        self.latest_goal_status = GoalStatus(status = GoalStatus.PENDING)
+        self.latest_goal_status = GoalStatus(status=GoalStatus.PENDING)
         self.latest_result = None
 
     def __eq__(self, o):
         return self.action_goal.goal_id.id == o.action_goal.goal_id.id
 
+    ## @brieft Hash function for CommStateMachine
+    def __hash__(self):
+        return hash(self.action_goal.goal_id.id)
+
     def set_state(self, state):
         rospy.logdebug("Transitioning CommState from %s to %s",
                        CommState.to_string(self.state), CommState.to_string(state))
@@ -404,7 +412,7 @@ class CommStateMachine:
         if self.action_goal.goal_id.id != action_feedback.status.goal_id.id:
             return
 
-        #with self.mutex:
+        # with self.mutex:
         if self.feedback_cb and self.state != CommState.DONE:
             self.feedback_cb(ClientGoalHandle(self), action_feedback.feedback)
 
@@ -432,21 +440,21 @@ class GoalManager:
         global g_goal_id
         id, g_goal_id = g_goal_id, g_goal_id + 1
         now = rospy.Time.now()
-        return GoalID(id = "%s-%i-%.3f" % \
-                          (rospy.get_caller_id(), id, now.to_sec()), stamp = now)
+        return GoalID(id="%s-%i-%.3f" % (rospy.get_caller_id(), id, now.to_sec()), stamp=now)
 
     def register_send_goal_fn(self, fn):
         self.send_goal_fn = fn
+
     def register_cancel_fn(self, fn):
         self.cancel_fn = fn
 
     ## Sends off a goal and starts tracking its status.
     ##
     ## @return ClientGoalHandle for the sent goal.
-    def init_goal(self, goal, transition_cb = None, feedback_cb = None):
-        action_goal = self.ActionGoal(header = Header(),
-                                      goal_id = self._generate_id(),
-                                      goal = goal)
+    def init_goal(self, goal, transition_cb=None, feedback_cb=None):
+        action_goal = self.ActionGoal(header=Header(),
+                                      goal_id=self._generate_id(),
+                                      goal=goal)
         action_goal.header.stamp = rospy.get_rostime()
 
         csm = CommStateMachine(action_goal, transition_cb, feedback_cb,
@@ -459,7 +467,6 @@ class GoalManager:
 
         return ClientGoalHandle(csm)
 
-
     # Pulls out the statuses that are still live (creating strong
     # references to them)
     def _get_live_statuses(self):
@@ -468,12 +475,10 @@ class GoalManager:
             live_statuses = filter(lambda x: x, live_statuses)
             return live_statuses
 
-
     ## Updates the statuses of all goals from the information in status_array.
     ##
     ## @param status_array (\c actionlib_msgs/GoalStatusArray)
     def update_statuses(self, status_array):
-        live_statuses = []
 
         with self.list_mutex:
             # Garbage collects dead status objects
@@ -482,7 +487,6 @@ class GoalManager:
         for status in self._get_live_statuses():
             status.update_status(status_array)
 
-
     def update_results(self, action_result):
         for status in self._get_live_statuses():
             status.update_result(action_result)
@@ -491,6 +495,7 @@ class GoalManager:
         for status in self._get_live_statuses():
             status.update_feedback(action_feedback)
 
+
 class ActionClient:
     ## @brief Constructs an ActionClient and opens connections to an ActionServer.
     ##
@@ -513,16 +518,22 @@ class ActionClient:
         except AttributeError:
             raise ActionException("Type is not an action spec: %s" % str(ActionSpec))
 
-        self.pub_goal = rospy.Publisher(rospy.remap_name(ns) + '/goal', self.ActionGoal, queue_size=10)
-        self.pub_cancel = rospy.Publisher(rospy.remap_name(ns) + '/cancel', GoalID, queue_size=10)
+        self.pub_queue_size = rospy.get_param('actionlib_client_pub_queue_size', 10)
+        if self.pub_queue_size < 0:
+            self.pub_queue_size = 10
+        self.pub_goal = rospy.Publisher(rospy.remap_name(ns) + '/goal', self.ActionGoal, queue_size=self.pub_queue_size)
+        self.pub_cancel = rospy.Publisher(rospy.remap_name(ns) + '/cancel', GoalID, queue_size=self.pub_queue_size)
 
         self.manager = GoalManager(ActionSpec)
         self.manager.register_send_goal_fn(self.pub_goal.publish)
         self.manager.register_cancel_fn(self.pub_cancel.publish)
 
-        self.status_sub = rospy.Subscriber(rospy.remap_name(ns) + '/status', GoalStatusArray, self._status_cb)
-        self.result_sub = rospy.Subscriber(rospy.remap_name(ns) + '/result', self.ActionResult, self._result_cb)
-        self.feedback_sub = rospy.Subscriber(rospy.remap_name(ns) + '/feedback', self.ActionFeedback, self._feedback_cb)
+        self.sub_queue_size = rospy.get_param('actionlib_client_sub_queue_size', -1)
+        if self.sub_queue_size < 0:
+            self.sub_queue_size = None
+        self.status_sub = rospy.Subscriber(rospy.remap_name(ns) + '/status', GoalStatusArray, callback=self._status_cb, queue_size=self.sub_queue_size)
+        self.result_sub = rospy.Subscriber(rospy.remap_name(ns) + '/result', self.ActionResult, callback=self._result_cb, queue_size=self.sub_queue_size)
+        self.feedback_sub = rospy.Subscriber(rospy.remap_name(ns) + '/feedback', self.ActionFeedback, callback=self._feedback_cb, queue_size=self.sub_queue_size)
 
     ## @brief Sends a goal to the action server
     ##
@@ -538,7 +549,7 @@ class ActionClient:
     ## message.
     ##
     ## @return ClientGoalHandle for the sent goal.
-    def send_goal(self, goal, transition_cb = None, feedback_cb = None):
+    def send_goal(self, goal, transition_cb=None, feedback_cb=None):
         return self.manager.init_goal(goal, transition_cb, feedback_cb)
 
     ## @brief Cancels all goals currently running on the action server.
@@ -546,23 +557,21 @@ class ActionClient:
     ## Preempts all goals running on the action server at the point
     ## that the cancel message is serviced by the action server.
     def cancel_all_goals(self):
-        cancel_msg = GoalID(stamp = rospy.Time.from_sec(0.0),
-                            id = "")
+        cancel_msg = GoalID(stamp=rospy.Time.from_sec(0.0), id="")
         self.pub_cancel.publish(cancel_msg)
 
     ## @brief Cancels all goals prior to a given timestamp
     ##
-    ## This preempts all goals running on the action server for which the 
+    ## This preempts all goals running on the action server for which the
     ## time stamp is earlier than the specified time stamp
     ## this message is serviced by the ActionServer.
 
     def cancel_goals_at_and_before_time(self, time):
-        cancel_msg = GoalID(stamp = time, id = "")
+        cancel_msg = GoalID(stamp=time, id="")
         self.pub_cancel.publish(cancel_msg)
-    
-    
+
     ## @brief [Deprecated] Use wait_for_server
-    def wait_for_action_server_to_start(self, timeout = rospy.Duration(0.0)):
+    def wait_for_action_server_to_start(self, timeout=rospy.Duration(0.0)):
         return self.wait_for_server(timeout)
 
     ## @brief Waits for the ActionServer to connect to this client
@@ -570,7 +579,7 @@ class ActionClient:
     ## Often, it can take a second for the action server & client to negotiate
     ## a connection, thus, risking the first few goals to be dropped. This call lets
     ## the user wait until the network connection to the server is negotiated
-    def wait_for_server(self, timeout = rospy.Duration(0.0)):
+    def wait_for_server(self, timeout=rospy.Duration(0.0)):
         started = False
         timeout_time = rospy.get_rostime() + timeout
         while not rospy.is_shutdown():
@@ -579,9 +588,9 @@ class ActionClient:
 
                 if self.pub_goal.impl.has_connection(server_id) and \
                         self.pub_cancel.impl.has_connection(server_id):
-                    #We'll also check that all of the subscribers have at least
-                    #one publisher, this isn't a perfect check, but without
-                    #publisher callbacks... it'll have to do
+                    # We'll also check that all of the subscribers have at least
+                    # one publisher, this isn't a perfect check, but without
+                    # publisher callbacks... it'll have to do
                     status_num_pubs = 0
                     for stat in self.status_sub.impl.get_stats()[1]:
                         if stat[4]:
@@ -617,5 +626,3 @@ class ActionClient:
 
     def _feedback_cb(self, msg):
         self.manager.update_feedbacks(msg)
-
-
